@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::Modules::AdminPerformanceLog;
@@ -11,8 +11,6 @@ package Kernel::Modules::AdminPerformanceLog;
 use strict;
 use warnings;
 
-our $ObjectManagerDisabled = 1;
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -20,34 +18,38 @@ sub new {
     my $Self = {%Param};
     bless( $Self, $Type );
 
+    # check needed objects
+    for (qw(ParamObject LayoutObject LogObject ConfigObject)) {
+        if ( !$Self->{$_} ) {
+            $Self->{LayoutObject}->FatalError( Message => "Got no $_!" );
+        }
+    }
+
     return $Self;
 }
 
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
-
     # is performance log disabled?
-    if ( !$ConfigObject->Get('PerformanceLog') ) {
-        $LayoutObject->Block(
+    if ( !$Self->{ConfigObject}->Get('PerformanceLog') ) {
+        $Self->{LayoutObject}->Block(
             Name => 'Disabled',
             Data => { %Param, },
         );
 
         # create & return output
-        my $Output = $LayoutObject->Header();
-        $Output .= $LayoutObject->NavigationBar();
-        $Output .= $LayoutObject->Output(
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+        $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminPerformanceLog',
             Data         => \%Param,
         );
-        $Output .= $LayoutObject->Footer();
+        $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
 
-    $LayoutObject->Block(
+    $Self->{LayoutObject}->Block(
         Name => 'Enabled',
         Data => { %Param, },
     );
@@ -56,15 +58,15 @@ sub Run {
     if ( $Self->{Subaction} eq 'Reset' ) {
 
         # challenge token check for write action
-        $LayoutObject->ChallengeTokenCheck();
+        $Self->{LayoutObject}->ChallengeTokenCheck();
 
         if ( !$Self->_DatabaseReset() ) {
-            $LayoutObject->FatalError();
+            $Self->{LayoutObject}->FatalError();
         }
         else {
 
             # redirect
-            return $LayoutObject->Redirect(
+            return $Self->{LayoutObject}->Redirect(
                 OP => "Action=$Self->{Action}",
             );
         }
@@ -73,18 +75,15 @@ sub Run {
     # show detail view
     elsif ( $Self->{Subaction} eq 'View' ) {
 
-        $LayoutObject->Block( Name => 'ActionList' );
-        $LayoutObject->Block( Name => 'ActionOverview' );
-
-        my $ParamObject = $Kernel::OM->Get('Kernel::System::Web::Request');
-        my %Action      = ();
-        my $MaxRequest  = 0;
-        my $Slot        = 60;
-        my $MinuteSlot  = $ParamObject->GetParam( Param => 'Minute' );
-        $Param{Minute} = $MinuteSlot;
-        my $Interface = $ParamObject->GetParam( Param => 'Interface' );
-        my $Module    = $ParamObject->GetParam( Param => 'Module' );
+        $Self->{LayoutObject}->Block( Name => 'ActionList' );
+        $Self->{LayoutObject}->Block( Name => 'ActionOverview' );
 
+        my %Action     = ();
+        my $MaxRequest = 0;
+        my $Slot       = 60;
+        my $MinuteSlot = $Self->{ParamObject}->GetParam( Param => 'Minute' );
+        my $Interface  = $Self->{ParamObject}->GetParam( Param => 'Interface' );
+        my $Module     = $Self->{ParamObject}->GetParam( Param => 'Module' );
         if ( $MinuteSlot < 31 ) {
             $Slot = 1;
         }
@@ -98,10 +97,10 @@ sub Run {
             $Slot = 30;
         }
         my $Data = $Self->_DatabaseRead();
-        $LayoutObject->Block(
+        $Self->{LayoutObject}->Block(
             Name => 'View',
             Data => {
-                Age => $LayoutObject->CustomerAge(
+                Age => $Self->{LayoutObject}->CustomerAge(
                     Age   => $MinuteSlot * 60,
                     Space => ' '
                 ),
@@ -110,14 +109,6 @@ sub Run {
                 Period    => $Slot,
             },
         );
-
-        $Param{Age} = $LayoutObject->CustomerAge(
-            Age   => $MinuteSlot * 60,
-            Space => ' '
-        );
-        $Param{Interface} = $Interface;
-        $Param{Module}    = $Module;
-
         my $Minute = 0;
         my $Count  = 1;
         while ( $Count <= $MinuteSlot ) {
@@ -180,9 +171,6 @@ sub Run {
         $Count  = 1;
         while ( $Count <= $MinuteSlot ) {
 
-            my $DateTimeObject = $Kernel::OM->Create('Kernel::System::DateTime');
-            $DateTimeObject->Subtract( Minutes => $Minute * 60 );
-
             # set output class
             if ( $Action{$Minute} ) {
                 my $Average = $Action{$Minute}->{Sum} / $Action{$Minute}->{Count};
@@ -190,26 +178,30 @@ sub Run {
                 my $I = 100 / $MaxRequest;
                 my $W = $Action{$Minute}->{Count} * $I || 1;
 
-                $LayoutObject->Block(
+                $Self->{LayoutObject}->Block(
                     Name => 'ViewRow',
                     Data => {
                         %{ $Action{$Minute} },
                         Average => $Average,
-                        Date    => $DateTimeObject->ToString(),
-                        Width   => $W . "%",
+                        Date    => $Self->{TimeObject}->SystemTime2TimeStamp(
+                            SystemTime => $Self->{TimeObject}->SystemTime() - $Minute * 60,
+                        ),
+                        Width => $W . "%",
                     },
                 );
             }
             else {
-                $LayoutObject->Block(
+                $Self->{LayoutObject}->Block(
                     Name => 'ViewRow',
                     Data => {
                         Min     => 0,
                         Max     => 0,
                         Count   => $Action{$Minute}->{Count} || '0',
                         Average => 0,
-                        Date    => $DateTimeObject->ToString(),
-                        Width   => '0%',
+                        Date    => $Self->{TimeObject}->SystemTime2TimeStamp(
+                            SystemTime => $Self->{TimeObject}->SystemTime() - $Minute * 60,
+                        ),
+                        Width => '0%',
                     },
                 );
             }
@@ -218,13 +210,13 @@ sub Run {
         }
 
         # create & return output
-        my $Output = $LayoutObject->Header();
-        $Output .= $LayoutObject->NavigationBar();
-        $Output .= $LayoutObject->Output(
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+        $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminPerformanceLog',
             Data         => \%Param,
         );
-        $Output .= $LayoutObject->Footer();
+        $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
 
@@ -233,24 +225,24 @@ sub Run {
 
         # get avarage times
         my $Data = [];
-        if ( $ConfigObject->Get('PerformanceLog') ) {
+        if ( $Self->{ConfigObject}->Get('PerformanceLog') ) {
 
             # check file size
             if ( $Self->_DatabaseCheck() ) {
-                $LayoutObject->Block(
+                $Self->{LayoutObject}->Block(
                     Name => 'Reset',
                     Data => {
-                        Size => sprintf "%.1f MB",
+                        Size => sprintf "%.1f MBytes",
                         ( $Self->_DatabaseCheck() / ( 1024 * 1024 ) ),
                     },
                 );
-                my $Output = $LayoutObject->Header();
-                $Output .= $LayoutObject->NavigationBar();
-                $Output .= $LayoutObject->Output(
+                my $Output = $Self->{LayoutObject}->Header();
+                $Output .= $Self->{LayoutObject}->NavigationBar();
+                $Output .= $Self->{LayoutObject}->Output(
                     TemplateFile => 'AdminPerformanceLog',
                     Data         => \%Param,
                 );
-                $Output .= $LayoutObject->Footer();
+                $Output .= $Self->{LayoutObject}->Footer();
                 return $Output;
             }
             else {
@@ -258,7 +250,7 @@ sub Run {
             }
         }
 
-        $LayoutObject->Block(
+        $Self->{LayoutObject}->Block(
             Name => 'Overview',
         );
 
@@ -325,11 +317,11 @@ sub Run {
                 }
             }
             if (%Sum) {
-                $LayoutObject->Block(
+                $Self->{LayoutObject}->Block(
                     Name => 'OverviewTable',
                     Data => {
                         Age =>
-                            $LayoutObject->CustomerAge(
+                            $Self->{LayoutObject}->CustomerAge(
                             Age   => $Minute * 60,
                             Space => ' '
                             ),
@@ -341,7 +333,7 @@ sub Run {
 
                     my $Average = $Sum{$Interface} / $Count{$Interface};
                     $Average =~ s/^(.*\.\d\d).+?$/$1/g;
-                    $LayoutObject->Block(
+                    $Self->{LayoutObject}->Block(
                         Name => 'OverviewInterface',
                         Data => {
                             Interface => $Interface,
@@ -359,7 +351,7 @@ sub Run {
                             my $Average = $Action{$Module}->{Sum}->{$Interface}
                                 / $Action{$Module}->{Count}->{$Interface};
                             $Average =~ s/^(.*\.\d\d).+?$/$1/g;
-                            $LayoutObject->Block(
+                            $Self->{LayoutObject}->Block(
                                 Name => 'OverviewRow',
                                 Data => {
                                     Interface => $Interface,
@@ -379,27 +371,25 @@ sub Run {
         }
 
         # create & return output
-        my $Output = $LayoutObject->Header();
-        $Output .= $LayoutObject->NavigationBar();
-        $Output .= $LayoutObject->Output(
+        my $Output = $Self->{LayoutObject}->Header();
+        $Output .= $Self->{LayoutObject}->NavigationBar();
+        $Output .= $Self->{LayoutObject}->Output(
             TemplateFile => 'AdminPerformanceLog',
             Data         => \%Param,
         );
-        $Output .= $LayoutObject->Footer();
+        $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
-    return;
 }
 
 sub _DatabaseCheck {
     my ( $Self, %Param ) = @_;
 
-    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
-    my $File         = $ConfigObject->Get('PerformanceLog::File');
+    my $File = $Self->{ConfigObject}->Get('PerformanceLog::File');
 
     # check file size
     my $FileSize = -s $File;
-    if ( $FileSize > ( 1024 * 1024 * $ConfigObject->Get('PerformanceLog::FileMax') ) ) {
+    if ( $FileSize > ( 1024 * 1024 * $Self->{ConfigObject}->Get('PerformanceLog::FileMax') ) ) {
         return $FileSize;
     }
     else {
@@ -410,8 +400,8 @@ sub _DatabaseCheck {
 sub _DatabaseReset {
     my ( $Self, %Param ) = @_;
 
-    my $File = $Kernel::OM->Get('Kernel::Config')->Get('PerformanceLog::File');
-    if ( !$Kernel::OM->Get('Kernel::System::Main')->FileDelete( Location => $File ) ) {
+    my $File = $Self->{ConfigObject}->Get('PerformanceLog::File');
+    if ( !$Self->{MainObject}->FileDelete( Location => $File ) ) {
         return;
     }
     else {
@@ -423,8 +413,8 @@ sub _DatabaseRead {
     my ( $Self, %Param ) = @_;
 
     my @Data     = ();
-    my $File     = $Kernel::OM->Get('Kernel::Config')->Get('PerformanceLog::File');
-    my $ArrayRef = $Kernel::OM->Get('Kernel::System::Main')->FileRead(
+    my $File     = $Self->{ConfigObject}->Get('PerformanceLog::File');
+    my $ArrayRef = $Self->{MainObject}->FileRead(
         Location => $File,
         Mode     => 'utf8',     # optional - binmode|utf8
         Result   => 'ARRAY',    # optional - SCALAR|ARRAY
@@ -432,7 +422,7 @@ sub _DatabaseRead {
     if ($ArrayRef) {
         for ( @{$ArrayRef} ) {
             my $Line = $_;
-            my @Row  = split( /::/, $Line );
+            my @Row = split( /::/, $Line );
             push( @Data, \@Row );
         }
     }
