@@ -1,6 +1,5 @@
 # --
-# Kernel/Output/HTML/ArticleCheckPGP.pm
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,9 +11,23 @@ package Kernel::Output::HTML::ArticleCheckPGP;
 use strict;
 use warnings;
 
+use MIME::Parser;
+
 use Kernel::System::Crypt;
 use Kernel::System::EmailParser;
 
+use Kernel::System::VariableCheck qw(:all);
+
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::Output::HTML::Layout',
+    'Kernel::System::DB',
+    'Kernel::System::Encode',
+    'Kernel::System::Log',
+    'Kernel::System::Main',
+    'Kernel::System::Ticket',
+);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -23,15 +36,23 @@ sub new {
     bless( $Self, $Type );
 
     # get needed objects
-    for (
-        qw(ConfigObject LogObject EncodeObject MainObject DBObject LayoutObject UserID TicketObject ArticleID)
-        )
-    {
+    $Self->{ConfigObject} = $Param{ConfigObject} || $Kernel::OM->Get('Kernel::Config');
+    $Self->{LogObject}    = $Param{LogObject}    || $Kernel::OM->Get('Kernel::System::Log');
+    $Self->{EncodeObject} = $Param{EncodeObject} || $Kernel::OM->Get('Kernel::System::Encode');
+    $Self->{MainObject}   = $Param{MainObject}   || $Kernel::OM->Get('Kernel::System::Main');
+    $Self->{DBObject}     = $Param{DBObject}     || $Kernel::OM->Get('Kernel::System::DB');
+    $Self->{TicketObject} = $Param{TicketObject} || $Kernel::OM->Get('Kernel::System::Ticket');
+    $Self->{LayoutObject} = $Param{LayoutObject} || $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
+    for (qw(UserID ArticleID)) {
         if ( $Param{$_} ) {
             $Self->{$_} = $Param{$_};
         }
         else {
-            $Self->{LogObject}->Log( Priority => 'error', Message => "Need $_!" );
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $_!"
+            );
         }
     }
 
@@ -50,6 +71,7 @@ sub Check {
     # check if article is an email
     return if $Param{Article}->{ArticleType} !~ /email/i;
 
+    my $StoreDecryptedData = $Self->{ConfigObject}->Get('PGP::StoreDecryptedData');
     $Self->{CryptObject} = Kernel::System::Crypt->new( %{$Self}, CryptType => 'PGP' );
 
     # check inline pgp crypt
@@ -73,14 +95,73 @@ sub Check {
             $Self->{Result} = \%Decrypt;
             $Param{Article}->{Body} = $Decrypt{Data};
 
-            # updated article body
-            $Self->{TicketObject}->ArticleUpdate(
-                TicketID  => $Param{Article}->{TicketID},
-                ArticleID => $Self->{ArticleID},
-                Key       => 'Body',
-                Value     => $Decrypt{Data},
-                UserID    => $Self->{UserID},
-            );
+            if ($StoreDecryptedData) {
+
+                # updated article body
+                $Self->{TicketObject}->ArticleUpdate(
+                    TicketID  => $Param{Article}->{TicketID},
+                    ArticleID => $Self->{ArticleID},
+                    Key       => 'Body',
+                    Value     => $Decrypt{Data},
+                    UserID    => $Self->{UserID},
+                );
+
+                # get a list of all article attachments
+                my %Index = $Self->{TicketObject}->ArticleAttachmentIndex(
+                    ArticleID => $Self->{ArticleID},
+                    UserID    => $Self->{UserID},
+                );
+
+                my @Attachments;
+                if ( IsHashRefWithData( \%Index ) ) {
+                    for my $FileID ( sort keys %Index ) {
+
+                        # get attachment details
+                        my %Attachment = $Self->{TicketObject}->ArticleAttachment(
+                            ArticleID => $Self->{ArticleID},
+                            FileID    => $FileID,
+                            UserID    => $Self->{UserID},
+                        );
+
+                        # store attachemnts attributes that might change after decryption
+                        my $AttachmentContent  = $Attachment{Content};
+                        my $AttachmentFilename = $Attachment{Filename};
+
+                        # try to decrypt the attachment, non ecrypted attachments will succeed too.
+                        %Decrypt = $Self->{CryptObject}->Decrypt( Message => $Attachment{Content} );
+
+                        if ( $Decrypt{Successful} ) {
+
+                            # set decrypted content
+                            $AttachmentContent = $Decrypt{Data};
+
+                            # remove .pgp .gpg or asc extensions (if any)
+                            $AttachmentFilename =~ s{ (\. [^\.]+) \. (?: pgp|gpg|asc) \z}{$1}msx;
+                        }
+
+                        # remember decrypted attachement, to add it later
+                        push @Attachments, {
+                            %Attachment,
+                            Content   => $AttachmentContent,
+                            Filename  => $AttachmentFilename,
+                            ArticleID => $Self->{ArticleID},
+                            UserID    => $Self->{UserID},
+                        };
+                    }
+
+                    # delete crypted attachments
+                    $Self->{TicketObject}->ArticleDeleteAttachment(
+                        ArticleID => $Self->{ArticleID},
+                        UserID    => $Self->{UserID},
+                    );
+
+                    # write decrypted attachments to the storage
+                    for my $Attachment (@Attachments) {
+                        $Self->{TicketObject}->ArticleWriteAttachment( %{$Attachment} );
+                    }
+                }
+            }
+
             push(
                 @Return,
                 {
@@ -103,8 +184,8 @@ sub Check {
         }
     }
 
-    # check inline pgp signature
-    if ( $Param{Article}->{Body} =~ m{ \Q-----BEGIN PGP SIGNED MESSAGE-----\E }xms ) {
+    # check inline pgp signature (but ignore if is in quoted text)
+    if ( $Param{Article}->{Body} =~ m{ ^\s* -----BEGIN [ ] PGP [ ] SIGNED [ ] MESSAGE----- }xms ) {
 
         # get original message
         my $Message = $Self->{TicketObject}->ArticlePlain(
@@ -157,13 +238,16 @@ sub Check {
             ArticleID => $Self->{ArticleID},
             UserID    => $Self->{UserID},
         );
-        use MIME::Parser;
         my $Parser = MIME::Parser->new();
         $Parser->decode_headers(0);
         $Parser->extract_nested_messages(0);
         $Parser->output_to_core('ALL');
+
+        # prevent modification of body by parser - required for bug #11755
+        $Parser->decode_bodies(0);
         my $Entity = $Parser->parse_data($Message);
-        my $Head   = $Entity->head();
+        $Parser->decode_bodies(1);
+        my $Head = $Entity->head();
         $Head->unfold();
         $Head->combine('Content-Type');
         my $ContentType = $Head->get('Content-Type');
@@ -189,11 +273,13 @@ sub Check {
                 );
             }
 
-            # decrypt
-            my $Cryped = $Entity->parts(1)->as_string();
+            # get crypted part of the mail
+            my $Crypted = $Entity->parts(1)->as_string();
 
-            # Encrypt it
-            my %Decrypt = $Self->{CryptObject}->Decrypt( Message => $Cryped, );
+            # decrypt it
+            my %Decrypt = $Self->{CryptObject}->Decrypt(
+                Message => $Crypted,
+            );
             if ( $Decrypt{Successful} ) {
                 $Entity = $Parser->parse_data( $Decrypt{Data} );
                 my $Head = $Entity->head();
@@ -205,8 +291,6 @@ sub Check {
                 # could be altered and a signature verify could fail. See Bug#9954
                 my $EntityCopy = $Entity->dup();
 
-                use Kernel::System::EmailParser;
-
                 my $ParserObject = Kernel::System::EmailParser->new(
                     %{$Self},
                     Entity => $EntityCopy,
@@ -214,30 +298,31 @@ sub Check {
 
                 my $Body = $ParserObject->GetMessageBody();
 
-                # updated article body
-                $Self->{TicketObject}->ArticleUpdate(
-                    TicketID  => $Param{Article}->{TicketID},
-                    ArticleID => $Self->{ArticleID},
-                    Key       => 'Body',
-                    Value     => $Body,
-                    UserID    => $Self->{UserID},
-                );
+                if ($StoreDecryptedData) {
 
-                # delete crypted attachments
-                $Self->{TicketObject}->ArticleDeleteAttachment(
-                    ArticleID => $Self->{ArticleID},
-                    UserID    => $Self->{UserID},
-                );
-
-                # write attachments to the storage
-                for my $Attachment ( $ParserObject->GetAttachments() ) {
-                    $Self->{TicketObject}->ArticleWriteAttachment(
-                        Content     => $Attachment->{Content},
-                        Filename    => $Attachment->{Filename},
-                        ContentType => $Attachment->{ContentType},
-                        ArticleID   => $Self->{ArticleID},
-                        UserID      => $Self->{UserID},
+                    # updated article body
+                    $Self->{TicketObject}->ArticleUpdate(
+                        TicketID  => $Param{Article}->{TicketID},
+                        ArticleID => $Self->{ArticleID},
+                        Key       => 'Body',
+                        Value     => $Body,
+                        UserID    => $Self->{UserID},
                     );
+
+                    # delete crypted attachments
+                    $Self->{TicketObject}->ArticleDeleteAttachment(
+                        ArticleID => $Self->{ArticleID},
+                        UserID    => $Self->{UserID},
+                    );
+
+                    # write attachments to the storage
+                    for my $Attachment ( $ParserObject->GetAttachments() ) {
+                        $Self->{TicketObject}->ArticleWriteAttachment(
+                            %{$Attachment},
+                            ArticleID => $Self->{ArticleID},
+                            UserID    => $Self->{UserID},
+                        );
+                    }
                 }
 
                 push(
