@@ -46,7 +46,7 @@ sub Run {
     }
 
     # get item definition
-    my $Text      = $Self->{LayoutObject}->{LanguageObject}->Get( $Param{Config}->{Name} );
+    my $Text      = $Self->{LayoutObject}->{LanguageObject}->Translate( $Param{Config}->{Name} );
     my $URL       = $Self->{LayoutObject}->{Baselink} . $Param{Config}->{Link};
     my $Priority  = $Param{Config}->{Priority};
     my $AccessKey = $Param{Config}->{AccessKey};
