@@ -1,6 +1,5 @@
 # --
-# Kernel/System/Ticket/Event/NotificationEvent.pm - a event module to send notifications
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -169,9 +168,24 @@ sub Run {
 
                     next VALUE if !$IsNotificationEventCondition;
 
+                    # Get match value from the dynamic field backend, if applicable (bug#12257).
+                    my $MatchValue;
+                    my $SearchFieldParameter = $DynamicFieldBackendObject->SearchFieldParameterBuild(
+                        DynamicFieldConfig => $DynamicFieldConfig,
+                        Profile            => {
+                            $Key => $Value,
+                        },
+                    );
+                    if ( defined $SearchFieldParameter->{Parameter}->{Equals} ) {
+                        $MatchValue = $SearchFieldParameter->{Parameter}->{Equals};
+                    }
+                    else {
+                        $MatchValue = $Value;
+                    }
+
                     $Match = $DynamicFieldBackendObject->ObjectMatch(
                         DynamicFieldConfig => $DynamicFieldConfig,
-                        Value              => $Value,
+                        Value              => $MatchValue,
                         ObjectAttributes   => \%Ticket,
                     );
 
